@@ -22,7 +22,7 @@
 #include <gsl/gsl_test.h>
 #include <gsl/gsl_ieee_utils.h>
 #include <gsl/gsl_math.h>
-#include "gsl_cblas.h"
+#include <gsl/gsl_cblas.h>
 
 #include "tests.h"
 
