@@ -24,6 +24,7 @@
 #include <stdlib.h>
 #include <gsl/gsl_errno.h>
 #include <gsl/gsl_types.h>
+#include <gsl/gsl_check_range.h>
 
 #undef __BEGIN_DECLS
 #undef __END_DECLS
@@ -51,6 +52,7 @@ gsl_combination *gsl_combination_calloc (const size_t n, const size_t k);
 void gsl_combination_init_first (gsl_combination * c);
 void gsl_combination_init_last (gsl_combination * c);
 void gsl_combination_free (gsl_combination * c);
+int gsl_combination_memcpy (gsl_combination * dest, const gsl_combination * src); 
 
 int gsl_combination_fread (FILE * stream, gsl_combination * c);
 int gsl_combination_fwrite (FILE * stream, const gsl_combination * c);
@@ -67,15 +69,13 @@ int gsl_combination_valid (gsl_combination * c);
 int gsl_combination_next (gsl_combination * c);
 int gsl_combination_prev (gsl_combination * c);
 
-GSL_VAR int gsl_check_range;
-
 #ifdef HAVE_INLINE
 
 extern inline
 size_t
 gsl_combination_get (const gsl_combination * c, const size_t i)
 {
-#ifndef GSL_RANGE_CHECK_OFF
+#if GSL_RANGE_CHECK
   if (i >= c->k)
     {
       GSL_ERROR_VAL ("index out of range", GSL_EINVAL, 0);
