@@ -21,27 +21,26 @@
 #define __GSL_CONST_MKS__
 
 #define GSL_CONST_MKS_SPEED_OF_LIGHT (2.99792458e8) /* m / s */
-#define GSL_CONST_MKS_GRAVITATIONAL_CONSTANT (6.67259e-11) /* m^3 / kg s^2 */
-#define GSL_CONST_MKS_PLANCKS_CONSTANT_H (6.6260755e-34) /* kg m^2 / s */
-#define GSL_CONST_MKS_PLANCKS_CONSTANT_HBAR (1.05457266913e-34) /* kg m^2 / s */
-#define GSL_CONST_MKS_VACUUM_PERMEABILITY (1.25663706144e-6) /* kg m / A^2 s^2 */
-#define GSL_CONST_MKS_ASTRONOMICAL_UNIT (1.495979e11) /* m */
+#define GSL_CONST_MKS_GRAVITATIONAL_CONSTANT (6.673e-11) /* m^3 / kg s^2 */
+#define GSL_CONST_MKS_PLANCKS_CONSTANT_H (6.62606876e-34) /* kg m^2 / s */
+#define GSL_CONST_MKS_PLANCKS_CONSTANT_HBAR (1.05457159642e-34) /* kg m^2 / s */
+#define GSL_CONST_MKS_ASTRONOMICAL_UNIT (1.49597870691e11) /* m */
 #define GSL_CONST_MKS_LIGHT_YEAR (9.46053620707e15) /* m */
-#define GSL_CONST_MKS_PARSEC (3.08567818589e16) /* m */
+#define GSL_CONST_MKS_PARSEC (3.08567758135e16) /* m */
 #define GSL_CONST_MKS_GRAV_ACCEL (9.80665e0) /* m / s^2 */
-#define GSL_CONST_MKS_ELECTRON_VOLT (1.60217733e-19) /* kg m^2 / s^2 */
-#define GSL_CONST_MKS_MASS_ELECTRON (9.10938961969e-31) /* kg */
-#define GSL_CONST_MKS_MASS_MUON (1.88353269879e-28) /* kg */
-#define GSL_CONST_MKS_MASS_PROTON (1.67262307095e-27) /* kg */
-#define GSL_CONST_MKS_MASS_NEUTRON (1.67492862142e-27) /* kg */
-#define GSL_CONST_MKS_RYDBERG (2.17987412173e-18) /* kg m^2 / s^2 */
-#define GSL_CONST_MKS_BOLTZMANN (1.3806513e-23) /* kg m^2 / K s^2 */
-#define GSL_CONST_MKS_BOHR_MAGNETON (9.27401542715e-24) /* A m^2 */
-#define GSL_CONST_MKS_NUCLEAR_MAGNETON (5.05078658357e-27) /* A m^2 */
-#define GSL_CONST_MKS_ELECTRON_MAGNETIC_MOMENT (9.28477005945e-24) /* A m^2 */
-#define GSL_CONST_MKS_PROTON_MAGNETIC_MOMENT (1.41060761072e-26) /* A m^2 */
-#define GSL_CONST_MKS_MOLAR_GAS (8.31447086363e0) /* kg m^2 / K mol s^2 */
-#define GSL_CONST_MKS_STANDARD_GAS_VOLUME (2.2413992e-2) /* m^3 / mol */
+#define GSL_CONST_MKS_ELECTRON_VOLT (1.602176462e-19) /* kg m^2 / s^2 */
+#define GSL_CONST_MKS_MASS_ELECTRON (9.10938188e-31) /* kg */
+#define GSL_CONST_MKS_MASS_MUON (1.88353109e-28) /* kg */
+#define GSL_CONST_MKS_MASS_PROTON (1.67262158e-27) /* kg */
+#define GSL_CONST_MKS_MASS_NEUTRON (1.67492716e-27) /* kg */
+#define GSL_CONST_MKS_RYDBERG (2.17987190389e-18) /* kg m^2 / s^2 */
+#define GSL_CONST_MKS_BOLTZMANN (1.3806503e-23) /* kg m^2 / K s^2 */
+#define GSL_CONST_MKS_BOHR_MAGNETON (9.27400899e-24) /* A m^2 */
+#define GSL_CONST_MKS_NUCLEAR_MAGNETON (5.05078317e-27) /* A m^2 */
+#define GSL_CONST_MKS_ELECTRON_MAGNETIC_MOMENT (9.28476362e-24) /* A m^2 */
+#define GSL_CONST_MKS_PROTON_MAGNETIC_MOMENT (1.410606633e-26) /* A m^2 */
+#define GSL_CONST_MKS_MOLAR_GAS (8.314472e0) /* kg m^2 / K mol s^2 */
+#define GSL_CONST_MKS_STANDARD_GAS_VOLUME (2.2710981e-2) /* m^3 / mol */
 #define GSL_CONST_MKS_MINUTE (6e1) /* s */
 #define GSL_CONST_MKS_HOUR (3.6e3) /* s */
 #define GSL_CONST_MKS_DAY (8.64e4) /* s */
@@ -80,7 +79,7 @@
 #define GSL_CONST_MKS_UK_TON (1.0160469088e3) /* kg */
 #define GSL_CONST_MKS_TROY_OUNCE (3.1103475e-2) /* kg */
 #define GSL_CONST_MKS_CARAT (2e-4) /* kg */
-#define GSL_CONST_MKS_UNIFIED_ATOMIC_MASS (1.6605402e-27) /* kg */
+#define GSL_CONST_MKS_UNIFIED_ATOMIC_MASS (1.66053873e-27) /* kg */
 #define GSL_CONST_MKS_GRAM_FORCE (9.80665e-3) /* kg m / s^2 */
 #define GSL_CONST_MKS_POUND_FORCE (4.44822161526e0) /* kg m / s^2 */
 #define GSL_CONST_MKS_KILOPOUND_FORCE (4.44822161526e3) /* kg m / s^2 */
@@ -94,12 +93,12 @@
 #define GSL_CONST_MKS_TORR (1.33322368421e2) /* kg / m s^2 */
 #define GSL_CONST_MKS_METER_OF_MERCURY (1.33322368421e5) /* kg / m s^2 */
 #define GSL_CONST_MKS_INCH_OF_MERCURY (3.38638815789e3) /* kg / m s^2 */
-#define GSL_CONST_MKS_INCH_OF_WATER (2.4884e2) /* kg / m s^2 */
+#define GSL_CONST_MKS_INCH_OF_WATER (2.490889e2) /* kg / m s^2 */
 #define GSL_CONST_MKS_PSI (6.89475729317e3) /* kg / m s^2 */
 #define GSL_CONST_MKS_POISE (1e-1) /* kg m^-1 s^-1 */
 #define GSL_CONST_MKS_STOKES (1e-4) /* m^2 / s */
-#define GSL_CONST_MKS_FARADAY (9.6485308989e4) /* A s / mol */
-#define GSL_CONST_MKS_ELECTRON_CHARGE (1.60217733e-19) /* A s */
+#define GSL_CONST_MKS_FARADAY (9.6485341472e4) /* A s / mol */
+#define GSL_CONST_MKS_ELECTRON_CHARGE (1.602176462e-19) /* A s */
 #define GSL_CONST_MKS_GAUSS (1e-4) /* kg / A s^2 */
 #define GSL_CONST_MKS_STILB (1e4) /* cd / m^2 */
 #define GSL_CONST_MKS_LUMEN (1e0) /* cd sr */
@@ -113,6 +112,13 @@
 #define GSL_CONST_MKS_RAD (1e-2) /* m^2 / s^2 */
 #define GSL_CONST_MKS_SOLAR_MASS (1.98892e30) /* kg */
 #define GSL_CONST_MKS_BOHR_RADIUS (5.291772083e-11) /* m */
+#define GSL_CONST_MKS_NEWTON (1e0) /* kg m / s^2 */
+#define GSL_CONST_MKS_DYNE (1e-5) /* kg m / s^2 */
+#define GSL_CONST_MKS_JOULE (1e0) /* kg m^2 / s^2 */
+#define GSL_CONST_MKS_ERG (1e-7) /* kg m^2 / s^2 */
+#define GSL_CONST_MKS_STEFAN_BOLTZMANN_CONSTANT (5.67039934436e-8) /* kg / K^4 s^3 */
+#define GSL_CONST_MKS_THOMSON_CROSS_SECTION (6.65245853542e-29) /* m^2 */
 #define GSL_CONST_MKS_VACUUM_PERMITTIVITY (8.854187817e-12) /* A^2 s^4 / kg m^3 */
+#define GSL_CONST_MKS_VACUUM_PERMEABILITY (1.25663706144e-6) /* kg m / A^2 s^2 */
 
 #endif /* __GSL_CONST_MKS__ */
