@@ -1,6 +1,6 @@
 /* gsl_pow_int.h
  * 
- * Copyright (C) 1996, 1997, 1998, 1999, 2000 Gerard Jungman, Brian Gough
+ * Copyright (C) 1996, 1997, 1998, 1999, 2000, 2004 Gerard Jungman, Brian Gough
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -32,7 +32,7 @@
 
 __BEGIN_DECLS
 
-#if HAVE_INLINE
+#ifdef HAVE_INLINE
 extern inline double gsl_pow_2(const double x);
 extern inline double gsl_pow_3(const double x);
 extern inline double gsl_pow_4(const double x);
