@@ -17,9 +17,9 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-double urand (void);
+static double urand (void);
 
-double urand (void) { 
+static double urand (void) { 
   static unsigned long int x = 1;
   x = (1103515245 * x + 12345) & 0x7fffffffUL ;
   return x / 2147483648.0  ;
