@@ -25,10 +25,10 @@
 #include <gsl/gsl_ieee_utils.h>
 #include <gsl/gsl_test.h>
 
-#if defined(HAVE_IRIX_IEEE_INTERFACE)
+#if HAVE_IRIX_IEEE_INTERFACE
 /* don't test denormals on IRIX */
 #else
-#ifdef HAVE_IEEE_DENORMALS
+#if HAVE_IEEE_DENORMALS
 #define TEST_DENORMAL 1
 #endif
 #endif
@@ -117,7 +117,7 @@ main (void)
     gsl_test_int (r.exponent, 0, "float x = -1.3304..., exponent is 0");
     gsl_test_str (r.mantissa, mantissa, "float x = -1.3304..., mantissa");
     gsl_test_int (r.type, GSL_IEEE_TYPE_NORMAL,
-		  "float x = -1.3304..., type is NORMAL");
+                  "float x = -1.3304..., type is NORMAL");
   }
 
   /* Check for a large positive NORMAL number (e.g. 3.37e31) (float) */
@@ -147,13 +147,13 @@ main (void)
     gsl_test_int (r.exponent, -102, "float x = 3.37e-31, exponent is -102");
     gsl_test_str (r.mantissa, mantissa, "float x = 3.37e-31, mantissa");
     gsl_test_int (r.type, GSL_IEEE_TYPE_NORMAL,
-		  "float x = 3.37e-31, type is NORMAL");
+                  "float x = 3.37e-31, type is NORMAL");
   }
 
   /* Check for FLT_MIN (smallest possible number that is not denormal) */
 
   {
-    float f = FLT_MIN;	
+    float f = FLT_MIN;  
     const char mantissa[] = "00000000000000000000000";
     gsl_ieee_float_rep r;
     gsl_ieee_float_to_rep (&f, &r);
@@ -184,7 +184,7 @@ main (void)
 
 #ifdef TEST_DENORMAL
   {
-    float f = FLT_MIN;	
+    float f = FLT_MIN;  
     char mantissa[] = "10000000000000000000000";
 
     int i;
@@ -192,18 +192,18 @@ main (void)
 
     for (i = 0; i < 23; i++)
       {
-	float x = f / (float)pow (2.0, 1 + (float) i);
-	mantissa[i] = '1';
-	gsl_ieee_float_to_rep (&x, &r);
+        float x = f / (float)pow (2.0, 1 + (float) i);
+        mantissa[i] = '1';
+        gsl_ieee_float_to_rep (&x, &r);
 
-	gsl_test_int (r.sign, 0, "float x = FLT_MIN/2^%d, sign is +", i + 1);
-	gsl_test_int (r.exponent, -127,
-		      "float x = FLT_MIN/2^%d, exponent is -127", i + 1);
-	gsl_test_str (r.mantissa, mantissa,
-		      "float x = FLT_MIN/2^%d, mantissa", i + 1);
-	gsl_test_int (r.type, GSL_IEEE_TYPE_DENORMAL,
-		      "float x = FLT_MIN/2^%d, type is DENORMAL", i + 1);
-	mantissa[i] = '0';
+        gsl_test_int (r.sign, 0, "float x = FLT_MIN/2^%d, sign is +", i + 1);
+        gsl_test_int (r.exponent, -127,
+                      "float x = FLT_MIN/2^%d, exponent is -127", i + 1);
+        gsl_test_str (r.mantissa, mantissa,
+                      "float x = FLT_MIN/2^%d, mantissa", i + 1);
+        gsl_test_int (r.type, GSL_IEEE_TYPE_DENORMAL,
+                      "float x = FLT_MIN/2^%d, type is DENORMAL", i + 1);
+        mantissa[i] = '0';
       }
   }
 #endif
@@ -211,7 +211,7 @@ main (void)
   /* Check for positive INFINITY (e.g. 2*FLT_MAX) */
 
   {
-    float f = FLT_MAX;	
+    float f = FLT_MAX;  
     const char mantissa[] = "00000000000000000000000";
 
     gsl_ieee_float_rep r;
@@ -229,7 +229,7 @@ main (void)
   /* Check for negative INFINITY (e.g. -2*FLT_MAX) */
 
   {
-    float f = FLT_MAX;	
+    float f = FLT_MAX;  
     const char mantissa[] = "00000000000000000000000";
 
     gsl_ieee_float_rep r;
@@ -328,7 +328,7 @@ main (void)
     gsl_test_int (r.exponent, 0, "double x = -1.3304..., exponent is 0");
     gsl_test_str (r.mantissa, mantissa, "double x = -1.3304..., mantissa");
     gsl_test_int (r.type, GSL_IEEE_TYPE_NORMAL,
-		  "double x = -1.3304..., type is NORMAL");
+                  "double x = -1.3304..., type is NORMAL");
   }
 
   /* Check for a large positive NORMAL number (e.g. 3.37e297) */
@@ -344,7 +344,7 @@ main (void)
     gsl_test_int (r.exponent, 988, "double x = 3.37e297, exponent is 998");
     gsl_test_str (r.mantissa, mantissa, "double x = 3.37e297, mantissa");
     gsl_test_int (r.type, GSL_IEEE_TYPE_NORMAL,
-		  "double x = 3.37e297, type is NORMAL");
+                  "double x = 3.37e297, type is NORMAL");
   }
 
   /* Check for a small positive NORMAL number (e.g. 3.37e-297) */
@@ -360,7 +360,7 @@ main (void)
     gsl_test_int (r.exponent, -985, "double x = 3.37e-297, exponent is -985");
     gsl_test_str (r.mantissa, mantissa, "double x = 3.37e-297, mantissa");
     gsl_test_int (r.type, GSL_IEEE_TYPE_NORMAL,
-		  "double x = 3.37e-297, type is NORMAL");
+                  "double x = 3.37e-297, type is NORMAL");
   }
 
   /* Check for DBL_MIN (smallest possible number that is not denormal) */
@@ -376,7 +376,7 @@ main (void)
     gsl_test_int (r.exponent, -1022, "double x = DBL_MIN, exponent is -1022");
     gsl_test_str (r.mantissa, mantissa, "double x = DBL_MIN, mantissa");
     gsl_test_int (r.type, GSL_IEEE_TYPE_NORMAL,
-		  "double x = DBL_MIN, type is NORMAL");
+                  "double x = DBL_MIN, type is NORMAL");
   }
 
   /* Check for DBL_MAX (largest possible number that is not Inf) */
@@ -392,7 +392,7 @@ main (void)
     gsl_test_int (r.exponent, 1023, "double x = DBL_MAX, exponent is 1023");
     gsl_test_str (r.mantissa, mantissa, "double x = DBL_MAX, mantissa");
     gsl_test_int (r.type, GSL_IEEE_TYPE_NORMAL,
-		  "double x = DBL_MAX, type is NORMAL");
+                  "double x = DBL_MAX, type is NORMAL");
   }
 
   /* Check for DENORMAL numbers (e.g. DBL_MIN/2^n) */
@@ -407,18 +407,18 @@ main (void)
 
     for (i = 0; i < 52; i++)
       {
-	double x = d / pow (2.0, 1 + (double) i);
-	mantissa[i] = '1';
-	gsl_ieee_double_to_rep (&x, &r);
+        double x = d / pow (2.0, 1 + (double) i);
+        mantissa[i] = '1';
+        gsl_ieee_double_to_rep (&x, &r);
 
-	gsl_test_int (r.sign, 0, "double x = DBL_MIN/2^%d, sign is +", i + 1);
-	gsl_test_int (r.exponent, -1023,
-		      "double x = DBL_MIN/2^%d, exponent", i + 1);
-	gsl_test_str (r.mantissa, mantissa,
-		      "double x = DBL_MIN/2^%d, mantissa", i + 1);
-	gsl_test_int (r.type, GSL_IEEE_TYPE_DENORMAL,
-		      "double x = DBL_MIN/2^%d, type is DENORMAL", i + 1);
-	mantissa[i] = '0';
+        gsl_test_int (r.sign, 0, "double x = DBL_MIN/2^%d, sign is +", i + 1);
+        gsl_test_int (r.exponent, -1023,
+                      "double x = DBL_MIN/2^%d, exponent", i + 1);
+        gsl_test_str (r.mantissa, mantissa,
+                      "double x = DBL_MIN/2^%d, mantissa", i + 1);
+        gsl_test_int (r.type, GSL_IEEE_TYPE_DENORMAL,
+                      "double x = DBL_MIN/2^%d, type is DENORMAL", i + 1);
+        mantissa[i] = '0';
       }
   }
 #endif
