@@ -240,7 +240,7 @@ int gsl_matrix_uint_set_col(gsl_matrix_uint * m, const size_t j, const gsl_vecto
 
 /* inline functions if you are using GCC */
 
-#if HAVE_INLINE
+#ifdef HAVE_INLINE
 extern inline 
 unsigned int
 gsl_matrix_uint_get(const gsl_matrix_uint * m, const size_t i, const size_t j)
