@@ -21,6 +21,7 @@
 #define __GSL_MULTIROOTS_H__
 
 #include <stdlib.h>
+#include <gsl/gsl_types.h>
 #include <gsl/gsl_math.h>
 #include <gsl/gsl_vector.h>
 #include <gsl/gsl_matrix.h>
@@ -90,6 +91,8 @@ int gsl_multiroot_fsolver_iterate (gsl_multiroot_fsolver * s);
 
 const char * gsl_multiroot_fsolver_name (const gsl_multiroot_fsolver * s);
 gsl_vector * gsl_multiroot_fsolver_root (const gsl_multiroot_fsolver * s);
+gsl_vector * gsl_multiroot_fsolver_dx (const gsl_multiroot_fsolver * s);
+gsl_vector * gsl_multiroot_fsolver_f (const gsl_multiroot_fsolver * s);
 
 /* Definition of vector-valued functions and gradient with parameters
    based on gsl_vector */
@@ -149,21 +152,23 @@ gsl_multiroot_fdfsolver_free (gsl_multiroot_fdfsolver * s);
 
 const char * gsl_multiroot_fdfsolver_name (const gsl_multiroot_fdfsolver * s);
 gsl_vector * gsl_multiroot_fdfsolver_root (const gsl_multiroot_fdfsolver * s);
+gsl_vector * gsl_multiroot_fdfsolver_dx (const gsl_multiroot_fdfsolver * s);
+gsl_vector * gsl_multiroot_fdfsolver_f (const gsl_multiroot_fdfsolver * s);
 
 int gsl_multiroot_test_delta (const gsl_vector * dx, const gsl_vector * x, 
                               double epsabs, double epsrel);
 
 int gsl_multiroot_test_residual (const gsl_vector * f, double epsabs);
 
-extern const gsl_multiroot_fsolver_type * gsl_multiroot_fsolver_dnewton;
-extern const gsl_multiroot_fsolver_type * gsl_multiroot_fsolver_broyden;
-extern const gsl_multiroot_fsolver_type * gsl_multiroot_fsolver_hybrid;
-extern const gsl_multiroot_fsolver_type * gsl_multiroot_fsolver_hybrids;
+GSL_VAR const gsl_multiroot_fsolver_type * gsl_multiroot_fsolver_dnewton;
+GSL_VAR const gsl_multiroot_fsolver_type * gsl_multiroot_fsolver_broyden;
+GSL_VAR const gsl_multiroot_fsolver_type * gsl_multiroot_fsolver_hybrid;
+GSL_VAR const gsl_multiroot_fsolver_type * gsl_multiroot_fsolver_hybrids;
 
-extern const gsl_multiroot_fdfsolver_type * gsl_multiroot_fdfsolver_newton;
-extern const gsl_multiroot_fdfsolver_type * gsl_multiroot_fdfsolver_gnewton;
-extern const gsl_multiroot_fdfsolver_type * gsl_multiroot_fdfsolver_hybridj;
-extern const gsl_multiroot_fdfsolver_type * gsl_multiroot_fdfsolver_hybridsj;
+GSL_VAR const gsl_multiroot_fdfsolver_type * gsl_multiroot_fdfsolver_newton;
+GSL_VAR const gsl_multiroot_fdfsolver_type * gsl_multiroot_fdfsolver_gnewton;
+GSL_VAR const gsl_multiroot_fdfsolver_type * gsl_multiroot_fdfsolver_hybridj;
+GSL_VAR const gsl_multiroot_fdfsolver_type * gsl_multiroot_fdfsolver_hybridsj;
 
 
 __END_DECLS
