@@ -24,6 +24,7 @@
 
 #include <stdio.h>
 #include <stdlib.h>
+#include <gsl/gsl_types.h>
 
 #undef __BEGIN_DECLS
 #undef __END_DECLS
@@ -107,16 +108,17 @@ gsl_odeiv_step;
  * gear2  : M=2 implicit Gear method
  */
 
-extern const gsl_odeiv_step_type *gsl_odeiv_step_rk2;
-extern const gsl_odeiv_step_type *gsl_odeiv_step_rk4;
-extern const gsl_odeiv_step_type *gsl_odeiv_step_rkf45;
-extern const gsl_odeiv_step_type *gsl_odeiv_step_rkck;
-extern const gsl_odeiv_step_type *gsl_odeiv_step_rk8pd;
-extern const gsl_odeiv_step_type *gsl_odeiv_step_rk2imp;
-extern const gsl_odeiv_step_type *gsl_odeiv_step_rk4imp;
-extern const gsl_odeiv_step_type *gsl_odeiv_step_bsimp;
-extern const gsl_odeiv_step_type *gsl_odeiv_step_gear1;
-extern const gsl_odeiv_step_type *gsl_odeiv_step_gear2;
+GSL_VAR const gsl_odeiv_step_type *gsl_odeiv_step_rk2;
+GSL_VAR const gsl_odeiv_step_type *gsl_odeiv_step_rk4;
+GSL_VAR const gsl_odeiv_step_type *gsl_odeiv_step_rkf45;
+GSL_VAR const gsl_odeiv_step_type *gsl_odeiv_step_rkck;
+GSL_VAR const gsl_odeiv_step_type *gsl_odeiv_step_rk8pd;
+GSL_VAR const gsl_odeiv_step_type *gsl_odeiv_step_rk2imp;
+GSL_VAR const gsl_odeiv_step_type *gsl_odeiv_step_rk2simp;
+GSL_VAR const gsl_odeiv_step_type *gsl_odeiv_step_rk4imp;
+GSL_VAR const gsl_odeiv_step_type *gsl_odeiv_step_bsimp;
+GSL_VAR const gsl_odeiv_step_type *gsl_odeiv_step_gear1;
+GSL_VAR const gsl_odeiv_step_type *gsl_odeiv_step_gear2;
 
 
 /* Constructor for specialized stepper objects.
@@ -194,6 +196,12 @@ gsl_odeiv_control * gsl_odeiv_control_standard_new(double eps_abs, double eps_re
 gsl_odeiv_control * gsl_odeiv_control_y_new(double eps_abs, double eps_rel);
 gsl_odeiv_control * gsl_odeiv_control_yp_new(double eps_abs, double eps_rel);
 
+/* This controller computes errors using different absolute errors for
+ * each component
+ *
+ *    D0 = eps_abs * scale_abs[i] + eps_rel * (a_y |y| + a_dydt h |y'|)
+ */
+gsl_odeiv_control * gsl_odeiv_control_scaled_new(double eps_abs, double eps_rel, double a_y, double a_dydt, const double scale_abs[], size_t dim);
 
 /* General evolution object.
  */
