@@ -77,7 +77,7 @@ gsl_sf_bessel_sequence_Jnu_e(double nu, gsl_mode_t mode, size_t size, double * v
     gsl_sf_result J0, J1;
     double Jp, J;
     double x;
-    int i = 0;
+    size_t i = 0;
 
     /* Calculate the first point. */
     x = v[0];
@@ -106,7 +106,7 @@ gsl_sf_bessel_sequence_Jnu_e(double nu, gsl_mode_t mode, size_t size, double * v
     while(v[i] < x_small && i < size) {
       if(v[i] <= x) {
         /* Strict ordering failure. */
-	GSL_ERROR ("error", GSL_EFAILED);
+        GSL_ERROR ("error", GSL_EFAILED);
       }
       x = v[i];
       gsl_sf_bessel_Jnu_e(nu, x, &J0);
@@ -134,7 +134,7 @@ gsl_sf_bessel_sequence_Jnu_e(double nu, gsl_mode_t mode, size_t size, double * v
 
       if(v[i] <= x) {
         /* Strict ordering failure. */
-	GSL_ERROR ("error", GSL_EFAILED);
+        GSL_ERROR ("error", GSL_EFAILED);
       }
 
       /* Integrate over interval up to next sample point.
