@@ -1,17 +1,17 @@
 /* specfunc/gamma_inc.c
- * 
+ *
  * Copyright (C) 1996, 1997, 1998, 1999, 2000 Gerard Jungman
- * 
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
@@ -26,6 +26,7 @@
 #include <gsl/gsl_sf_exp.h>
 #include <gsl/gsl_sf_log.h>
 #include <gsl/gsl_sf_gamma.h>
+#include <gsl/gsl_sf_expint.h>
 
 #include "error.h"
 
@@ -46,11 +47,18 @@ gamma_inc_D(const double a, const double x, gsl_sf_result * result)
     return GSL_SUCCESS;
   }
   else {
-    double mu = (x-a)/a;
-    double term1;
     gsl_sf_result gstar;
     gsl_sf_result ln_term;
-    gsl_sf_log_1plusx_mx_e(mu, &ln_term);  /* log(1+mu) - mu */
+    double term1;
+    if (x < 0.5*a) {
+      double u = x/a;   
+      double ln_u = log(u);
+      ln_term.val = ln_u - u + 1.0;
+      ln_term.err = (fabs(ln_u) + fabs(u) + 1.0) * GSL_DBL_EPSILON;
+    } else {
+      double mu = (x-a)/a;
+      gsl_sf_log_1plusx_mx_e(mu, &ln_term);  /* log(1+mu) - mu */
+    };
     gsl_sf_gammastar_e(a, &gstar);
     term1 = exp(a*ln_term.val)/sqrt(2.0*M_PI*a);
     result->val  = term1/gstar.val;
@@ -58,6 +66,7 @@ gamma_inc_D(const double a, const double x, gsl_sf_result * result)
     result->err += gstar.err/fabs(gstar.val) * fabs(result->val);
     return GSL_SUCCESS;
   }
+
 }
 
 
@@ -83,7 +92,7 @@ gamma_inc_P_series(const double a, const double x, gsl_sf_result * result)
 
   result->val  = D.val * sum;
   result->err  = D.err * fabs(sum);
-  result->err += 2.0 * GSL_DBL_EPSILON * fabs(result->val);
+  result->err += (1.0 + n) * GSL_DBL_EPSILON * fabs(result->val);
 
   if(n == nmax)
     GSL_ERROR ("error", GSL_EMAXITER);
@@ -120,7 +129,7 @@ gamma_inc_Q_large_x(const double a, const double x, gsl_sf_result * result)
   result->err += 2.0 * GSL_DBL_EPSILON * fabs(result->val);
 
   if(n == nmax)
-    GSL_ERROR ("error", GSL_EMAXITER);
+    GSL_ERROR ("error in large x asymptotic", GSL_EMAXITER);
   else
     return stat_D;
 }
@@ -128,7 +137,6 @@ gamma_inc_Q_large_x(const double a, const double x, gsl_sf_result * result)
 
 /* Uniform asymptotic for x near a, a and x large.
  * See [Temme, p. 285]
- * FIXME: need c1 coefficient
  */
 static
 int
@@ -146,17 +154,21 @@ gamma_inc_Q_asymp_unif(const double a, const double x, gsl_sf_result * result)
   double R;
   double c0, c1;
 
-  gsl_sf_erfc_e(eta*M_SQRT2*rta, &erfc);
+  /* This used to say erfc(eta*M_SQRT2*rta), which is wrong.
+   * The sqrt(2) is in the denominator. Oops.
+   * Fixed: [GJ] Mon Nov 15 13:25:32 MST 2004
+   */
+  gsl_sf_erfc_e(eta*rta/M_SQRT2, &erfc);
 
   if(fabs(eps) < GSL_ROOT5_DBL_EPSILON) {
     c0 = -1.0/3.0 + eps*(1.0/12.0 - eps*(23.0/540.0 - eps*(353.0/12960.0 - eps*589.0/30240.0)));
-    c1 = 0.0;
+    c1 = -1.0/540.0 - eps/288.0;
   }
   else {
-    double rt_term;
-    rt_term = sqrt(-2.0 * ln_term.val/(eps*eps));
+    const double rt_term = sqrt(-2.0 * ln_term.val/(eps*eps));
+    const double lam = x/a;
     c0 = (1.0 - 1.0/rt_term)/eps;
-    c1 = 0.0;
+    c1 = -(eta*eta*eta * (lam*lam + 10.0*lam + 1.0) - 12.0 * eps*eps*eps) / (12.0 * eta*eta*eta*eps*eps*eps);
   }
 
   R = exp(-0.5*a*eta*eta)/(M_SQRT2*M_SQRTPI*rta) * (c0 + c1/a);
@@ -169,55 +181,34 @@ gamma_inc_Q_asymp_unif(const double a, const double x, gsl_sf_result * result)
 }
 
 
-/* Continued fraction for Q.
+/* Continued fraction which occurs in evaluation
+ * of Q(a,x) or Gamma(a,x).
  *
- * Q(a,x) = D(a,x) a/x F(a,x)
- *             1   (1-a)/x  1/x  (2-a)/x   2/x  (3-a)/x
- *  F(a,x) =  ---- ------- ----- -------- ----- -------- ...
- *            1 +   1 +     1 +   1 +      1 +   1 +
+ *              1   (1-a)/x  1/x  (2-a)/x   2/x  (3-a)/x
+ *   F(a,x) =  ---- ------- ----- -------- ----- -------- ...
+ *             1 +   1 +     1 +   1 +      1 +   1 +
  *
- * Hans E. Plesser, 2002-01-22 (hans dot plesser at itf dot nlh dot no):
+ * Hans E. Plesser, 2002-01-22 (hans dot plesser at itf dot nlh dot no).
  *
- * Since the Gautschi equivalent series method for CF evaluation may lead 
- * to singularities, I have replaced it with the modified Lentz algorithm
- * given in
- *
- * I J Thompson and A R Barnett
- * Coulomb and Bessel Functions of Complex Arguments and Order
- * J Computational Physics 64:490-509 (1986)
- *
- * In consequence, gamma_inc_Q_CF_protected() is now obsolete and has been 
- * removed. 
- *
- * Identification of terms between the above equation for F(a, x) and
- * the first equation in the appendix of Thompson&Barnett is as follows:
- *
- *    b_0 = 0, b_n = 1 for all n > 0
- *
- *    a_1 = 1
- *    a_n = (n/2-a)/x    for n even
- *    a_n = (n-1)/(2x)   for n odd
+ * Split out from gamma_inc_Q_CF() by GJ [Tue Apr  1 13:16:41 MST 2003].
+ * See gamma_inc_Q_CF() below.
  *
  */
-
-static
-int
-gamma_inc_Q_CF(const double a, const double x, gsl_sf_result * result)
+static int
+gamma_inc_F_CF(const double a, const double x, gsl_sf_result * result)
 {
   const int    nmax  =  5000;
   const double small =  gsl_pow_3 (GSL_DBL_EPSILON);
 
-  gsl_sf_result D;
-  const int stat_D = gamma_inc_D(a, x, &D);
-
   double hn = 1.0;           /* convergent */
   double Cn = 1.0 / small;
   double Dn = 1.0;
   int n;
 
-  /* n == 1 has a_1, b_1, b_0 independent of a,x, 
+  /* n == 1 has a_1, b_1, b_0 independent of a,x,
      so that has been done by hand                */
-  for ( n = 2 ; n < nmax ; n++ ) {
+  for ( n = 2 ; n < nmax ; n++ )
+  {
     double an;
     double delta;
 
@@ -235,19 +226,63 @@ gamma_inc_Q_CF(const double a, const double x, gsl_sf_result * result)
     Dn = 1.0 / Dn;
     delta = Cn * Dn;
     hn *= delta;
-    if(fabs(delta-1) < GSL_DBL_EPSILON) break;
+    if(fabs(delta-1.0) < GSL_DBL_EPSILON) break;
   }
 
-  result->val  = D.val * (a/x) * hn;
-  result->err  = D.err * fabs((a/x) * hn);
+  result->val = hn;
+  result->err = 2.0*GSL_DBL_EPSILON * fabs(hn);
   result->err += GSL_DBL_EPSILON * (2.0 + 0.5*n) * fabs(result->val);
 
   if(n == nmax)
-    GSL_ERROR ("error", GSL_EMAXITER);
+    GSL_ERROR ("error in CF for F(a,x)", GSL_EMAXITER);
   else
-    return stat_D;
+    return GSL_SUCCESS;
 }
 
+
+/* Continued fraction for Q.
+ *
+ * Q(a,x) = D(a,x) a/x F(a,x)
+ *
+ * Hans E. Plesser, 2002-01-22 (hans dot plesser at itf dot nlh dot no):
+ *
+ * Since the Gautschi equivalent series method for CF evaluation may lead
+ * to singularities, I have replaced it with the modified Lentz algorithm
+ * given in
+ *
+ * I J Thompson and A R Barnett
+ * Coulomb and Bessel Functions of Complex Arguments and Order
+ * J Computational Physics 64:490-509 (1986)
+ *
+ * In consequence, gamma_inc_Q_CF_protected() is now obsolete and has been
+ * removed.
+ *
+ * Identification of terms between the above equation for F(a, x) and
+ * the first equation in the appendix of Thompson&Barnett is as follows:
+ *
+ *    b_0 = 0, b_n = 1 for all n > 0
+ *
+ *    a_1 = 1
+ *    a_n = (n/2-a)/x    for n even
+ *    a_n = (n-1)/(2x)   for n odd
+ *
+ */
+static
+int
+gamma_inc_Q_CF(const double a, const double x, gsl_sf_result * result)
+{
+  gsl_sf_result D;
+  gsl_sf_result F;
+  const int stat_D = gamma_inc_D(a, x, &D);
+  const int stat_F = gamma_inc_F_CF(a, x, &F);
+
+  result->val  = D.val * (a/x) * F.val;
+  result->err  = D.err * fabs((a/x) * F.val) + fabs(D.val * a/x * F.err);
+
+  return GSL_ERROR_SELECT_2(stat_F, stat_D);
+}
+
+
 /* Useful for small a and x. Handles the subtraction analytically.
  */
 static
@@ -271,14 +306,14 @@ gamma_inc_Q_series(const double a, const double x, gsl_sf_result * result)
     const double c4 = -0.04166666666666666667
                        * (-1.758243446661483480 + lnx)
                        * (-0.764428657272716373 + lnx)
-		       * ( 0.723980571623507657 + lnx)
-		       * ( 4.107554191916823640 + lnx);
+                       * ( 0.723980571623507657 + lnx)
+                       * ( 4.107554191916823640 + lnx);
     const double c5 = -0.0083333333333333333
                        * (-2.06563396085715900 + lnx)
-		       * (-1.28459889470864700 + lnx)
-		       * (-0.27583535756454143 + lnx)
-		       * ( 1.33677371336239618 + lnx)
-		       * ( 5.17537282427561550 + lnx);
+                       * (-1.28459889470864700 + lnx)
+                       * (-0.27583535756454143 + lnx)
+                       * ( 1.33677371336239618 + lnx)
+                       * ( 5.17537282427561550 + lnx);
     const double c6 = -0.0013888888888888889
                        * (-2.30814336454783200 + lnx)
                        * (-1.65846557706987300 + lnx)
@@ -341,7 +376,7 @@ gamma_inc_Q_series(const double a, const double x, gsl_sf_result * result)
       sum += (a+1.0)/(a+n+1.0)*t;
       if(fabs(t/sum) < GSL_DBL_EPSILON) break;
     }
-    
+
     if(n == nmax)
       stat_sum = GSL_EMAXITER;
     else
@@ -356,12 +391,65 @@ gamma_inc_Q_series(const double a, const double x, gsl_sf_result * result)
 }
 
 
+/* series for small a and x, but not defined for a == 0 */
+static int
+gamma_inc_series(double a, double x, gsl_sf_result * result)
+{
+  gsl_sf_result Q;
+  gsl_sf_result G;
+  const int stat_Q = gamma_inc_Q_series(a, x, &Q);
+  const int stat_G = gsl_sf_gamma_e(a, &G);
+  result->val = Q.val * G.val;
+  result->err = fabs(Q.val * G.err) + fabs(Q.err * G.val);
+  result->err += 2.0 * GSL_DBL_EPSILON * fabs(result->val);
+
+  return GSL_ERROR_SELECT_2(stat_Q, stat_G);
+}
+
+
+static int
+gamma_inc_a_gt_0(double a, double x, gsl_sf_result * result)
+{
+  /* x > 0 and a > 0; use result for Q */
+  gsl_sf_result Q;
+  gsl_sf_result G;
+  const int stat_Q = gsl_sf_gamma_inc_Q_e(a, x, &Q);
+  const int stat_G = gsl_sf_gamma_e(a, &G);
+
+  result->val = G.val * Q.val;
+  result->err = fabs(G.val * Q.err) + fabs(G.err * Q.val);
+  result->err += 2.0*GSL_DBL_EPSILON * fabs(result->val);
+
+  return GSL_ERROR_SELECT_2(stat_G, stat_Q);
+}
+
+
+static int
+gamma_inc_CF(double a, double x, gsl_sf_result * result)
+{
+  gsl_sf_result F;
+  gsl_sf_result pre;
+  const int stat_F = gamma_inc_F_CF(a, x, &F);
+  const int stat_E = gsl_sf_exp_e((a-1.0)*log(x) - x, &pre);
+
+  result->val = F.val * pre.val;
+  result->err = fabs(F.err * pre.val) + fabs(F.val * pre.err);
+  result->err += (2.0 + fabs(a)) * GSL_DBL_EPSILON * fabs(result->val);
+
+  return GSL_ERROR_SELECT_2(stat_F, stat_E);
+}
+
+
+/* evaluate Gamma(0,x), x > 0 */
+#define GAMMA_INC_A_0(x, result) gsl_sf_expint_E1_e(x, result)
+
+
 /*-*-*-*-*-*-*-*-*-*-*-* Functions with Error Codes *-*-*-*-*-*-*-*-*-*-*-*/
 
 int
 gsl_sf_gamma_inc_Q_e(const double a, const double x, gsl_sf_result * result)
 {
-  if(a <= 0.0 || x < 0.0) {
+  if(a < 0.0 || x < 0.0) {
     DOMAIN_ERROR(result);
   }
   else if(x == 0.0) {
@@ -369,6 +457,12 @@ gsl_sf_gamma_inc_Q_e(const double a, const double x, gsl_sf_result * result)
     result->err = 0.0;
     return GSL_SUCCESS;
   }
+  else if(a == 0.0)
+  {
+    result->val = 0.0;
+    result->err = 0.0;
+    return GSL_SUCCESS;
+  }
   else if(x <= 0.5*a) {
     /* If the series is quick, do that. It is
      * robust and simple.
@@ -401,7 +495,7 @@ gsl_sf_gamma_inc_Q_e(const double a, const double x, gsl_sf_result * result)
        * it is somewhat pointless to try this there;
        * the function is rapidly decreasing for
        * x large and x > a, and it will just
-       * underflow in that region anyway. We 
+       * underflow in that region anyway. We
        * catch that case in the standard
        * large-x method.
        */
@@ -412,7 +506,7 @@ gsl_sf_gamma_inc_Q_e(const double a, const double x, gsl_sf_result * result)
     }
   }
   else {
-    if(a < 0.8*x) {
+    if(0.8*a < x) {
       /* Continued fraction again. The convergence
        * is a little slower here, but that is fine.
        * We have to trade that off against the slow
@@ -498,6 +592,65 @@ gsl_sf_gamma_inc_P_e(const double a, const double x, gsl_sf_result * result)
 }
 
 
+int
+gsl_sf_gamma_inc_e(const double a, const double x, gsl_sf_result * result)
+{
+  if(x < 0.0) {
+    DOMAIN_ERROR(result);
+  }
+  else if(x == 0.0) {
+    return gsl_sf_gamma_e(a, result);
+  }
+  else if(a == 0.0)
+  {
+    return GAMMA_INC_A_0(x, result);
+  }
+  else if(a > 0.0)
+  {
+    return gamma_inc_a_gt_0(a, x, result);
+  }
+  else if(x > 0.25)
+  {
+    /* continued fraction seems to fail for x too small; otherwise
+       it is ok, independent of the value of |x/a|, because of the
+       non-oscillation in the expansion, i.e. the CF is
+       un-conditionally convergent for a < 0 and x > 0
+     */
+    return gamma_inc_CF(a, x, result);
+  }
+  else if(fabs(a) < 0.5)
+  {
+    return gamma_inc_series(a, x, result);
+  }
+  else
+  {
+    /* a = fa + da; da >= 0 */
+    const double fa = floor(a);
+    const double da = a - fa;
+
+    gsl_sf_result g_da;
+    const int stat_g_da = ( da > 0.0 ? gamma_inc_a_gt_0(da, x, &g_da)
+                                     : GAMMA_INC_A_0(x, &g_da));
+
+    double alpha = da;
+    double gax = g_da.val;
+
+    /* Gamma(alpha-1,x) = 1/(alpha-1) (Gamma(a,x) - x^(alpha-1) e^-x) */
+    do
+    {
+      const double shift = exp(-x + (alpha-1.0)*log(x));
+      gax = (gax - shift) / (alpha - 1.0);
+      alpha -= 1.0;
+    } while(alpha > a);
+
+    result->val = gax;
+    result->err = 2.0*(1.0 + fabs(a))*GSL_DBL_EPSILON*fabs(gax);
+    return stat_g_da;
+  }
+
+}
+
+
 /*-*-*-*-*-*-*-*-*-* Functions w/ Natural Prototypes *-*-*-*-*-*-*-*-*-*-*/
 
 #include "eval.h"
@@ -511,3 +664,8 @@ double gsl_sf_gamma_inc_Q(const double a, const double x)
 {
   EVAL_RESULT(gsl_sf_gamma_inc_Q_e(a, x, &result));
 }
+
+double gsl_sf_gamma_inc(const double a, const double x)
+{
+   EVAL_RESULT(gsl_sf_gamma_inc_e(a, x, &result));
+}
