@@ -119,7 +119,10 @@ gsl_sf_legendre_Pl_e(const int l, const double x, gsl_sf_result * result)
   }
   else if(l == 2) {
     result->val = 0.5 * (3.0*x*x - 1.0);
-    result->err = 3.0 * GSL_DBL_EPSILON * fabs(result->val);
+    result->err = GSL_DBL_EPSILON * (fabs(3.0*x*x) + 1.0);
+    /*result->err = 3.0 * GSL_DBL_EPSILON * fabs(result->val);
+      removed this old bogus estimate [GJ]
+      */
     return GSL_SUCCESS;
   }
   else if(x == 1.0) {
@@ -210,7 +213,7 @@ gsl_sf_legendre_Pl_array(const int lmax, const double x, double * result_array)
     /* upward recurrence: l P_l = (2l-1) z P_{l-1} - (l-1) P_{l-2} */
 
     double p_ellm2 = 1.0;    /* P_0(x) */
-    double p_ellm1 = x;	   /* P_1(x) */
+    double p_ellm1 = x;    /* P_1(x) */
     double p_ell = p_ellm1;
     int ell;
 
@@ -286,11 +289,11 @@ gsl_sf_legendre_Plm_e(const int l, const int m, const double x, gsl_sf_result *
    * about overflow. Calculate an approximate exponent which
    * measures the normalization of this thing.
    */
-  double dif = l-m;
-  double sum = l+m;
-  double exp_check = 0.5 * log(2.0*l+1.0) 
-                   + 0.5 * dif * (log(dif)-1.0)
-                   - 0.5 * sum * (log(sum)-1.0);
+  const double dif = l-m;
+  const double sum = l+m;
+  const double t_d = ( dif == 0.0 ? 0.0 : 0.5 * dif * (log(dif)-1.0) );
+  const double t_s = ( dif == 0.0 ? 0.0 : 0.5 * sum * (log(sum)-1.0) );
+  const double exp_check = 0.5 * log(2.0*l+1.0) + t_d - t_s;
 
   /* CHECK_POINTER(result) */
 
@@ -353,11 +356,11 @@ gsl_sf_legendre_Plm_array(const int lmax, const int m, const double x, double *
    * about overflow. Calculate an approximate exponent which
    * measures the normalization of this thing.
    */
-  double dif = lmax-m;
-  double sum = lmax+m;
-  double exp_check = 0.5 * log(2.0*lmax+1.0) 
-                     + 0.5 * dif * (log(dif)-1.0)
-                     - 0.5 * sum * (log(sum)-1.0);
+  const double dif = lmax-m;
+  const double sum = lmax+m;
+  const double t_d = ( dif == 0.0 ? 0.0 : 0.5 * dif * (log(dif)-1.0) );
+  const double t_s = ( dif == 0.0 ? 0.0 : 0.5 * sum * (log(sum)-1.0) );
+  const double exp_check = 0.5 * log(2.0*lmax+1.0) + t_d - t_s;
 
   /* CHECK_POINTER(result_array) */
 
@@ -455,6 +458,7 @@ gsl_sf_legendre_Plm_deriv_array(
             result_deriv_array[ell-m] = -0.25 * sgn * x * (ell - 1.0)*ell*(ell+1.0)*(ell+2.0);
           }
         }
+        return GSL_SUCCESS;
       }
       else 
       {
@@ -462,6 +466,7 @@ gsl_sf_legendre_Plm_deriv_array(
         if(1.0 - fabs(x) < GSL_DBL_EPSILON)
         {
           for(ell = m; ell <= lmax; ell++) result_deriv_array[ell-m] = 0.0;
+          return GSL_SUCCESS;
         }
         else
         {
@@ -693,6 +698,7 @@ gsl_sf_legendre_sphPlm_deriv_array(
       if(1.0 - fabs(x) < GSL_DBL_EPSILON)
       {
         for(ell = m; ell <= lmax; ell++) result_deriv_array[ell-m] = 0.0;
+        return GSL_SUCCESS;
       }
       else
       {
