@@ -162,7 +162,7 @@ int gsl_vector_char_add_constant (gsl_vector_char * a, const double x);
 
 int gsl_vector_char_isnull (const gsl_vector_char * v);
 
-#if HAVE_INLINE
+#ifdef HAVE_INLINE
 
 extern inline
 char
