@@ -23,6 +23,7 @@
 #include <stdlib.h>
 #include <gsl/gsl_types.h>
 #include <gsl/gsl_errno.h>
+#include <gsl/gsl_check_range.h>
 #include <gsl/gsl_block_long.h>
 
 #undef __BEGIN_DECLS
@@ -135,7 +136,7 @@ int gsl_vector_long_fread (FILE * stream, gsl_vector_long * v);
 int gsl_vector_long_fwrite (FILE * stream, const gsl_vector_long * v);
 int gsl_vector_long_fscanf (FILE * stream, gsl_vector_long * v);
 int gsl_vector_long_fprintf (FILE * stream, const gsl_vector_long * v,
-			      const char *format);
+                              const char *format);
 
 int gsl_vector_long_memcpy (gsl_vector_long * dest, const gsl_vector_long * src);
 
@@ -161,15 +162,13 @@ int gsl_vector_long_add_constant (gsl_vector_long * a, const double x);
 
 int gsl_vector_long_isnull (const gsl_vector_long * v);
 
-GSL_VAR int gsl_check_range;
-
 #ifdef HAVE_INLINE
 
 extern inline
 long
 gsl_vector_long_get (const gsl_vector_long * v, const size_t i)
 {
-#ifndef GSL_RANGE_CHECK_OFF
+#if GSL_RANGE_CHECK
   if (i >= v->size)
     {
       GSL_ERROR_VAL ("index out of range", GSL_EINVAL, 0);
@@ -182,7 +181,7 @@ extern inline
 void
 gsl_vector_long_set (gsl_vector_long * v, const size_t i, long x)
 {
-#ifndef GSL_RANGE_CHECK_OFF
+#if GSL_RANGE_CHECK
   if (i >= v->size)
     {
       GSL_ERROR_VOID ("index out of range", GSL_EINVAL);
@@ -195,7 +194,7 @@ extern inline
 long *
 gsl_vector_long_ptr (gsl_vector_long * v, const size_t i)
 {
-#ifndef GSL_RANGE_CHECK_OFF
+#if GSL_RANGE_CHECK
   if (i >= v->size)
     {
       GSL_ERROR_NULL ("index out of range", GSL_EINVAL);
@@ -208,7 +207,7 @@ extern inline
 const long *
 gsl_vector_long_const_ptr (const gsl_vector_long * v, const size_t i)
 {
-#ifndef GSL_RANGE_CHECK_OFF
+#if GSL_RANGE_CHECK
   if (i >= v->size)
     {
       GSL_ERROR_NULL ("index out of range", GSL_EINVAL);
